==> lima-swing-0.8.1-sources.jar: org/chorem/lima/ui/vatchart/VatChartTreeTableModel.java <==
/*
 * #%L
 * Lima :: Swing
 * %%
 * Copyright (C) 2008 - 2012 CodeLutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package org.chorem.lima.ui.vatchart;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.business.api.VatStatementService;
import org.chorem.lima.business.exceptions.AlreadyExistVatStatementException;
import org.chorem.lima.business.exceptions.NotAllowedLabelException;
import org.chorem.lima.entity.VatStatement;
import org.chorem.lima.entity.VatStatementImpl;
import org.chorem.lima.service.LimaServiceFactory;
import org.chorem.lima.util.ErrorHelper;
import org.jdesktop.swingx.treetable.AbstractTreeTableModel;

import javax.swing.tree.TreePath;
import java.util.List;

import static org.nuiton.i18n.I18n.t;

public class VatChartTreeTableModel extends AbstractTreeTableModel {

    /** log. */
    private static final Log log = LogFactory.getLog(VatChartViewHandler.class);

    /** Services. */
    protected final VatStatementService vatStatementService;

    protected ErrorHelper errorHelper;

    /** Model constructor. Initiate account service used here. */
    public VatChartTreeTableModel() {
        //create root for the tree
        super(new VatStatementImpl());
        // Gets factory service 
        vatStatementService =
                LimaServiceFactory.getService(
                        VatStatementService.class);
    }


    @Override
    public int getColumnCount() {
        return 2;
    }

    @Override
    public String getColumnName(int column) {
        String res = null;
        switch (column) {
            case 0:
                res = t("lima.table.label");
                break;
            case 1:
                res = t("lima.table.account");
                break;
        }
        return res;
    }

    @Override
    public int getChildCount(Object node) {
        int result = 0;
        if (node == getRoot()) {
            result = vatStatementService.
                    getChildrenVatStatement(null).size();
        } else {
            VatStatement parentVatStatementHeader =
                    (VatStatement) node;
            result = vatStatementService.getChildrenVatStatement(
                    parentVatStatementHeader).size();
        }
        return result;
    }

    @Override
    public Object getChild(Object parent, int index) {
        Object result = null;
        if (parent == getRoot()) {
            List<VatStatement> vatStatements =
                    vatStatementService.getChildrenVatStatement(null);
            result = vatStatements.get(index);
        } else {
            VatStatement parentVatStatement =
                    (VatStatement) parent;
            List<VatStatement> vatStatements = vatStatementService.
                    getChildrenVatStatement(parentVatStatement);
            result = vatStatements.get(index);
        }
        return result;
    }

    @Override
    public int getIndexOfChild(Object parent, Object child) {
        int result = 0;

        if (parent == getRoot()) {
            List<VatStatement> vatStatements =
                    vatStatementService.getChildrenVatStatement(null);
            result = vatStatements.indexOf(child);
        } else {
            VatStatement parentVatStatement =
                    (VatStatement) parent;
            List<VatStatement> vatStatements = vatStatementService.
                    getChildrenVatStatement(parentVatStatement);
            result = vatStatements.indexOf(child);
        }
        return result;
    }

    @Override
    public Object getValueAt(Object node, int column) {
        Object result = "n/a";
        VatStatement vatStatement = (VatStatement) node;
        switch (column) {
            case 0:
                result = vatStatement.getLabel();
                break;
            case 1:
                result = vatStatement.getAccounts();
                break;
        }
        return result;
    }

    @Override
    public boolean isCellEditable(Object node, int column) {
        return column == 1 && isLeaf(node);
    }

    @Override
    public boolean isLeaf(Object node) {
        return getChildCount(node) == 0;
    }


    /** Refresh VatStatementChart. */
    public void refreshTree() {

        modelSupport.fireNewRoot();
    }


    /**
     * Add VatStatement(path can be null).
     *
     * @param path
     * @param vatStatement
     */
    public void addVatStatement(TreePath path, VatStatement vatStatement) {
        // Calling account service
        //fixed bug when path is null
        VatStatement parentVatStatementHeader = null;
        if (path != null) {
            parentVatStatementHeader =
                    (VatStatement) path.getLastPathComponent();
        }
        try {
            vatStatementService.createVatStatement(
                    parentVatStatementHeader, vatStatement);
        } catch (AlreadyExistVatStatementException alreadyExistVatStatement) {
            errorHelper.showErrorMessage(t("lima.financialStatement.error.alreadyExistFinancialStatement",
                    alreadyExistVatStatement.getVatStatementLabel(), alreadyExistVatStatement.getMasterLabel()));
        } catch (NotAllowedLabelException notAllowedLabel) {
            errorHelper.showErrorMessage(t("lima.error.notAllowedLabel",
                    notAllowedLabel.getLabel()));
        }
        modelSupport.fireTreeStructureChanged(path);
    }


    /**
     * Update vatStatement
     *
     * @param path
     * @param vatStatement
     */
    public void updateVatStatement(TreePath path, VatStatement vatStatement) {

        vatStatementService.updateVatStatement(vatStatement);
        modelSupport.fireTreeStructureChanged(path);
    }

    /**
     * Remove vatStatement
     *
     * @param path
     * @param vatStatement
     */
    public void removeVatStatementObject(TreePath path, VatStatement vatStatement) {
        // Calling account service
        int index = getIndexOfChild(
                path.getParentPath().getLastPathComponent(), vatStatement);
        vatStatementService.removeVatStatement(vatStatement);
        modelSupport.fireChildRemoved(path.getParentPath(), index, vatStatement);
    }


    @Override
    public void setValueAt(Object value, Object node, int column) {
        VatStatement vatStatement = (VatStatement) node;
        vatStatement.setAccounts((String) value);
            vatStatementService.updateVatStatement(vatStatement);
    }


}

==> lima-swing-0.8.2-sources.jar: org/chorem/lima/ui/vatchart/VatChartTreeTableModel.java <==
/*
 * #%L
 * Lima :: Swing
 * %%
 * Copyright (C) 2008 - 2012 CodeLutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package org.chorem.lima.ui.vatchart;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.business.api.VatStatementService;
import org.chorem.lima.business.exceptions.AlreadyExistVatStatementException;
import org.chorem.lima.business.exceptions.NotAllowedLabelException;
import org.chorem.lima.entity.VatStatement;
import org.chorem.lima.entity.VatStatementImpl;
import org.chorem.lima.business.LimaServiceFactory;
import org.chorem.lima.util.ErrorHelper;
import org.jdesktop.swingx.treetable.AbstractTreeTableModel;

import javax.swing.tree.TreePath;
import java.util.List;

import static org.nuiton.i18n.I18n.t;

public class VatChartTreeTableModel extends AbstractTreeTableModel {

    /** log. */
    private static final Log log = LogFactory.getLog(VatChartViewHandler.class);

    /** Services. */
    protected final VatStatementService vatStatementService;

    protected ErrorHelper errorHelper;

    /** Model constructor. Initiate account service used here. */
    public VatChartTreeTableModel() {
        //create root for the tree
        super(new VatStatementImpl());
        // Gets factory service 
        vatStatementService =
                LimaServiceFactory.getService(
                        VatStatementService.class);
    }


    @Override
    public int getColumnCount() {
        return 2;
    }

    @Override
    public String getColumnName(int column) {
        String res = null;
        switch (column) {
            case 0:
                res = t("lima.table.label");
                break;
            case 1:
                res = t("lima.table.account");
                break;
        }
        return res;
    }

    @Override
    public int getChildCount(Object node) {
        int result = 0;
        if (node == getRoot()) {
            result = vatStatementService.
                    getChildrenVatStatement(null).size();
        } else {
            VatStatement parentVatStatementHeader =
                    (VatStatement) node;
            result = vatStatementService.getChildrenVatStatement(
                    parentVatStatementHeader).size();
        }
        return result;
    }

    @Override
    public Object getChild(Object parent, int index) {
        Object result = null;
        if (parent == getRoot()) {
            List<VatStatement> vatStatements =
                    vatStatementService.getChildrenVatStatement(null);
            result = vatStatements.get(index);
        } else {
            VatStatement parentVatStatement =
                    (VatStatement) parent;
            List<VatStatement> vatStatements = vatStatementService.
                    getChildrenVatStatement(parentVatStatement);
            result = vatStatements.get(index);
        }
        return result;
    }

    @Override
    public int getIndexOfChild(Object parent, Object child) {
        int result = 0;

        if (parent == getRoot()) {
            List<VatStatement> vatStatements =
                    vatStatementService.getChildrenVatStatement(null);
            result = vatStatements.indexOf(child);
        } else {
            VatStatement parentVatStatement =
                    (VatStatement) parent;
            List<VatStatement> vatStatements = vatStatementService.
                    getChildrenVatStatement(parentVatStatement);
            result = vatStatements.indexOf(child);
        }
        return result;
    }

    @Override
    public Object getValueAt(Object node, int column) {
        Object result = "n/a";
        VatStatement vatStatement = (VatStatement) node;
        switch (column) {
            case 0:
                result = vatStatement.getLabel();
                break;
            case 1:
                result = vatStatement.getAccounts();
                break;
        }
        return result;
    }

    @Override
    public boolean isCellEditable(Object node, int column) {
        return column == 1 && isLeaf(node);
    }

    @Override
    public boolean isLeaf(Object node) {
        return getChildCount(node) == 0;
    }


    /** Refresh VatStatementChart. */
    public void refreshTree() {

        modelSupport.fireNewRoot();
    }


    /**
     * Add VatStatement(path can be null).
     *
     * @param path
     * @param vatStatement
     */
    public void addVatStatement(TreePath path, VatStatement vatStatement) {
        // Calling account service
        //fixed bug when path is null
        VatStatement parentVatStatementHeader = null;
        if (path != null) {
            parentVatStatementHeader =
                    (VatStatement) path.getLastPathComponent();
        }
        try {
            vatStatementService.createVatStatement(
                    parentVatStatementHeader, vatStatement);
        } catch (AlreadyExistVatStatementException alreadyExistVatStatement) {
            errorHelper.showErrorMessage(t("lima.financialStatement.error.alreadyExistFinancialStatement",
                    alreadyExistVatStatement.getVatStatementLabel(), alreadyExistVatStatement.getMasterLabel()));
        } catch (NotAllowedLabelException notAllowedLabel) {
            errorHelper.showErrorMessage(t("lima.error.notAllowedLabel",
                    notAllowedLabel.getLabel()));
        }
        modelSupport.fireTreeStructureChanged(path);
    }


    /**
     * Update vatStatement
     *
     * @param path
     * @param vatStatement
     */
    public void updateVatStatement(TreePath path, VatStatement vatStatement) {

        vatStatementService.updateVatStatement(vatStatement);
        modelSupport.fireTreeStructureChanged(path);
    }

    /**
     * Remove vatStatement
     *
     * @param path
     * @param vatStatement
     */
    public void removeVatStatementObject(TreePath path, VatStatement vatStatement) {
        // Calling account service
        int index = getIndexOfChild(
                path.getParentPath().getLastPathComponent(), vatStatement);
        vatStatementService.removeVatStatement(vatStatement);
        modelSupport.fireChildRemoved(path.getParentPath(), index, vatStatement);
    }


    @Override
    public void setValueAt(Object value, Object node, int column) {
        VatStatement vatStatement = (VatStatement) node;
        vatStatement.setAccounts((String) value);
            vatStatementService.updateVatStatement(vatStatement);
    }


}
